@@ -19,6 +19,118 @@ import gzip
 import math
 import datetime
 import time
+from collections import Counter
+
+
+def is_number(data):
+    """is_number方法用于判断是否为数字
+
+    Parameters
+    ----------
+    data :
+        任意数据
+    Returns
+    ----------
+    """
+    try:
+        float(data)
+        return True
+    except ValueError:
+        pass
+
+    try:
+        import unicodedata
+        unicodedata.numeric(data)
+        return True
+    except (TypeError, ValueError):
+        pass
+    return False
+
+
+def type_assert(*ty_args, **ty_kwargs):
+    """type_assert方法用于强制确认输入格式
+
+    @type_assert(int, b=str)
+    f(a, b)
+
+    Parameters
+    ----------
+    Returns
+    ----------
+    """
+    from inspect import signature
+    from functools import wraps
+
+    def decorate(func):
+        # If in optimized mode, disable type checking
+        if not __debug__:
+            return func
+
+        # Map function argument names to supplied types
+        sig = signature(func)
+        bound_types = sig.bind_partial(*ty_args, **ty_kwargs).arguments
+
+        @wraps(func)
+        def wrapper(*args, **kwargs):
+            bound_values = sig.bind(*args, **kwargs)
+            # Enforce type assertions across supplied arguments
+            for name, value in bound_values.arguments.items():
+                if name in bound_types:
+                    if not isinstance(value, bound_types[name]):
+                        raise TypeError(
+                            'Argument {} must be {}'.format(
+                                name, bound_types[name]))
+            return func(*args, **kwargs)
+        return wrapper
+    return decorate
+
+
+def bins_by_step(start, end, step):
+    """bins_by_step方法用于等距分箱
+
+    Parameters
+    ----------
+    start : float
+        最小值
+    end : float
+        最大值
+    step : float
+        步长
+
+    Returns
+    ----------
+    """
+    if start >= end:
+        raise ValueError(u'start is greater than or equal to end')
+    ret = [start]
+    while True:
+        if ret[-1] + step >= end:
+            if ret[-1] == end:
+                break
+            ret.append(end)
+            break
+        ret.append(ret[-1] + step)
+    return ret
+
+
+def counter(data, n=None):
+    """counter方法用于统计元素数量
+
+    Parameters
+    ----------
+    data : list
+        列表数据
+    n : int
+        前n个元素
+    Returns
+    ----------
+    """
+    ret = Counter(data)
+    if not n:
+        ret = ret.most_common(len(ret))
+    else:
+        ret = ret.most_common(n)
+    return ret
 
 
 def is_nan(data):
@@ -26,7 +138,8 @@ def is_nan(data):
 
     Parameters
     ----------
-    param : str
+    data : anytype
+        任何数据类型
 
     Returns
     ----------
@@ -58,8 +171,10 @@ def is_type(data, typ):
 
     Parameters
     ----------
-    param : str
-
+    data : anydata
+        任何数据
+    typ ： anytype
+        需要确认的数据类型
     Returns
     ----------
     """
@@ -298,8 +413,8 @@ def diff_set(l1, l2):
     return list(set(l1).difference(set(l2)))
 
 
-def deff_set_num(l1, l2):
-    """deff_set方法用于差集数量
+def diff_set_num(l1, l2):
+    """diff_set方法用于差集数量
 
     Parameters
     ----------
